/*
 * Copyright (c) 2014, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package com.sun.glass.ui.monocle;
import com.sun.glass.utils.NativeLibLoader;

class AndroidPlatform extends NativePlatform {

    AndroidPlatform() {
        NativeLibLoader.loadLibrary("glass_monocle");
    }

    @Override
    protected InputDeviceRegistry createInputDeviceRegistry() {
        return AndroidInputDeviceRegistry.getInstance();
    }

    @Override
    protected NativeCursor createCursor() {
        return logSelectedCursor(new NullCursor());
    }

    @Override
    protected NativeScreen createScreen() {
        return new AndroidScreen();
    }

    /** Create the accelerated screen for this platform
     *
     * @param attributes a sequence of pairs (GLAttibute, value)
     * @throws GLException
     */
    @Override
    public synchronized AcceleratedScreen getAcceleratedScreen(
            int[] attributes) throws GLException {
        if (accScreen == null) {
            accScreen = new AndroidAcceleratedScreen(attributes);
        }
        return accScreen;
    }

}
